message_on_change is a small python program, that let's you check if a url has changed since the starting of the script.
This can be useful for
<li>
    Awaiting some results on some website
</li>
<li>
    Monitoring the update schedule of some sites
</li>
